(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
(*                                                                     *)
(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  Distributed only by permission.                                    *)
(*                                                                     *)
(***********************************************************************)
(* XV thumbnail loader *)
(* XV thumbnails are thumbnail files created by an application "xv" and
   they are stored in .xvpics directory. This module provides loading
   of these thumbnail files. *)

val load : string -> string * Index8.t
    (* returns image info and its thumbnail *)

val save : string -> string -> Index8.t -> unit
    (* save xv thumbnail *)
    (* Index8.t must be 80x80 at most *)

val create : Image.t -> Index8.t
